@@ -15,12 +15,12 @@ def forside(self):
     forsideDict = {
         "aktuelt": [],
         "kommunikation": {"beskeder": [], "dokumenter": []},
-        "undervisning": {"spørgeskemaer": [], "opgaveaflevering": [], "lektier": []},
+        "undervisning": {},
         "skema": []
     }
 
     for tr in soup.find("div", {"id": "s_m_Content_Content_aktueltIsland_pa"}).find_all("tr", {"class": "DashWithScroll textTop"}):
-        content = tr.find("td", {"class": "infoCol"})
+        content = tr.find("td", {"class": "infoCol"}).find("span")
         contentStr = str(content)
         for span in content.find_all("span", {"class": "bb_b"}):
             new = copy.copy(span)
@@ -48,11 +48,16 @@ def forside(self):
                 pass
 
     undervisning = soup.find("div", {"id": "s_m_Content_Content_undervisningIsland_pa"})
-    for id, type in [["s_m_Content_Content_SpoergeSkemaerInfo", "spørgeskemaer"], ["s_m_Content_Content_ElevOpgaveAfleveringer", "opgaveaflevering"], ["s_m_Content_Content_LektierOversigt", "lektier"]]:
-        for tr in undervisning.find("table", {"id": id}).find_all("tr"):
+    headings = undervisning.find_all("div", {"role": "heading"})
+    tables = undervisning.find_all("table")
+
+    for i in range(len(headings)):
+        navn = headings[i].find("span", {"class": "dashboardLinkHeaderText"}).text.lower().replace(" ", "_")
+        forsideDict["undervisning"][navn] = []
+        for tr in tables[i].find_all("tr"):
             tds = tr.find_all("td")
             try:
-                forsideDict["undervisning"][type].append({
+                forsideDict["undervisning"][navn].append({
                     "navn": tds[1].text,
                     "dato": tds[2].get("title"),
                     "id": re.search("id=\d+", str(tds[1].find("a").get("href"))).group().replace("id=", ""),
